@@ -8,14 +8,14 @@ from pathlib import Path
 import yaml
 import re
 
+from .alertbase import AlertBase
 from .libs.crawlerdb import CrawlerDB
 from .parserbase import ParserBase
 from .rulebase import RuleBase
-from .util.color import Color
-from .util.logger import Logger
+from filecrawler.libs.color import Color
+from filecrawler.libs.logger import Logger
 from .__meta__ import __version__, __description__
 from .util.tools import Tools
-from yaml.loader import SafeLoader, FullLoader
 
 
 class Configuration(object):
@@ -36,6 +36,7 @@ class Configuration(object):
     company = []
     tasks = 5
     tasks_integrator = 2
+    evidences_path = './evidences'
 
     indexed_chars = 1000000
     excludes = [
@@ -53,7 +54,8 @@ class Configuration(object):
     add_filesize = True
     remove_deleted = True
     add_as_inner_object = False
-    store_source = False
+    store_source = True
+    store_leaks_evidences = True
     index_empty_files = False
     attributes_support = False
     raw_metadata = False
@@ -133,6 +135,7 @@ class Configuration(object):
                 )
                 sys.exit(1)
 
+            Configuration.initialized = False
             Configuration.create_config()
             return
 
@@ -203,21 +206,25 @@ class Configuration(object):
                 '{!} {R}error: index name {O}%s{R} is not valid.{W}\r\n' % args.args.index_name)
             exit(1)
 
-        if args.args.path is None or args.args.path.strip() == '' or not os.listdir(args.args.path):
+        if args.args.path is None or args.args.path.strip() == '' or not os.path.isdir(args.args.path):
             Color.pl(
                 '{!} {R}error: path {O}%s{R} is not valid.{W}\r\n' % args.args.path)
             exit(1)
 
         Configuration.path = str(Path(args.args.path).resolve())
 
+        iname = Tools.sanitize_filename(Configuration.index_name)
+        base_path = Path(expanduser(f'~/.filecrawler/{iname}/'))
+
+        Configuration.evidences_path = Path(f'{base_path}/evidences/').resolve()
+        if not Configuration.evidences_path.exists():
+            Configuration.evidences_path.mkdir(parents=True)
+
         if not module.load_from_arguments(args.args):
             Configuration.mandatory()
 
         Configuration.module = module
 
-        if module.check_database:
-            Configuration.module.open_db(args=args.args, check=True)
-
         try:
 
             if not os.path.isfile(Configuration.config_file):
@@ -247,6 +254,7 @@ class Configuration(object):
                     Configuration.remove_deleted = general.get('remove_deleted', Configuration.remove_deleted)
                     Configuration.add_as_inner_object = general.get('add_as_inner_object', Configuration.add_as_inner_object)
                     Configuration.store_source = general.get('store_source', Configuration.store_source)
+                    Configuration.store_leaks_evidences = general.get('store_leaks_evidences', Configuration.store_leaks_evidences)
                     Configuration.attributes_support = general.get('attributes_support', Configuration.attributes_support)
                     Configuration.raw_metadata = general.get('raw_metadata', Configuration.raw_metadata)
                     Configuration.xml_support = general.get('xml_support', Configuration.xml_support)
@@ -280,6 +288,11 @@ class Configuration(object):
                 if not module.load_config(data):
                     Configuration.mandatory()
 
+                alerts = AlertBase.load_alerters(data.get('alerts', {}))
+                if alerts is not None and len(alerts) > 0:
+                    #Need this to store and send image alerts
+                    Configuration.store_leaks_evidences = True
+
         except IOError as x:
             if x.errno == errno.EACCES:
                 Color.pl('{!} {R}error: could not open {G}%s {O}permission denied{R}{W}\r\n' % Configuration.config_file)
@@ -317,8 +330,7 @@ class Configuration(object):
                 Color.pl('{!} {R}error: invalid ignore_above size {G}%s{W}\r\n' % Configuration.ignore_above)
                 sys.exit(1)
 
-        iname = Tools.sanitize_filename(Configuration.index_name)
-        db_name = Path(expanduser(f'~/.filecrawler/{iname}/filecrawler.db'))
+        db_name = Path(f'{base_path}/filecrawler.db')
         if args.args.db_file.strip() != '':
             db_name = Path(args.args.db_file.strip())
 
@@ -339,6 +351,8 @@ class Configuration(object):
         except Exception as e:
             raise e
 
+        Logger.pl('     {C}evidences path:{O} %s{W}' % Configuration.evidences_path)
+
         Logger.pl('     {C}index path:{O} %s{W}' % Configuration.path)
 
         if Configuration.git_support:
@@ -354,10 +368,29 @@ class Configuration(object):
             else:
                 Logger.pl('     {C}git version:{O} %s{W}' % git_ver)
 
+        if Configuration.verbose >= 2:
+            Configuration.print_config()
+
         Logger.pl('  ')
 
+    @staticmethod
+    def print_config():
+        with open(Configuration.config_file, 'r') as f:
+            data = dict(yaml.load(f, Loader=yaml.FullLoader))
+            Logger.pl('\n{+} {W}Running config: {W}')
+            Logger.pl('{GR}%s{W}' % yaml.dump(data, sort_keys=False, default_flow_style=False))
+
     @staticmethod
     def create_config():
+        sample_config = Configuration.get_config_sample()
+
+        with open(Configuration.config_file, 'w') as f:
+            yaml.dump(sample_config, f, sort_keys=False, default_flow_style=False)
+
+        Logger.pl('{+} {W}Config file created at {O}%s{W}\n' % Configuration.config_file)
+
+    @staticmethod
+    def get_config_sample() -> dict:
         from .crawlerbase import CrawlerBase
         sample_config = {
             'general': {
@@ -372,6 +405,7 @@ class Configuration(object):
                 'remove_deleted': Configuration.remove_deleted,
                 'add_as_inner_object': Configuration.add_as_inner_object,
                 'store_source': Configuration.store_source,
+                'store_leaks_evidences': Configuration.store_leaks_evidences,
                 'index_empty_files': Configuration.index_empty_files,
                 'attributes_support': Configuration.attributes_support,
                 'raw_metadata': Configuration.raw_metadata,
@@ -400,11 +434,11 @@ class Configuration(object):
                 if Configuration.verbose >= 1:
                     Tools.print_error(e)
 
+        alerts = AlertBase.get_config_sample()
+        if alerts is not None and len(alerts) > 0:
+            sample_config.update(dict(alerts=alerts))
 
-        with open(Configuration.config_file, 'w') as f:
-            yaml.dump(sample_config, f, sort_keys=False, default_flow_style=False)
-
-        Logger.pl('{+} {W}Config file created at {O}%s{W}\n' % Configuration.config_file)
+        return sample_config
 
     @staticmethod
     def get_banner():
@@ -421,7 +455,7 @@ class Configuration(object):
     @staticmethod
     def dump():
         ''' (Colorful) string representation of the configuration '''
-        from .util.color import Color
+        from filecrawler.libs.color import Color
 
         max_len = 20
         for key in Configuration.__dict__.keys():
