@@ -1,10 +1,4 @@
-import json
-from pathlib import Path
-
 from filecrawler.libs.file import File
-from filecrawler.libs.parser import Parser
-from filecrawler.util.color import Color
-from filecrawler.util.logger import Logger
 from filecrawler.parserbase import ParserBase
 
 
@@ -19,8 +13,6 @@ class OfficeParser(ParserBase):
         super().__init__('Document Parser', 'Parser for Document files')
 
     def parse(self, file: File) -> dict:
-        from filecrawler.config import Configuration
-
         data = self.ocr_file(file)
 
         return data
