@@ -1,15 +1,4 @@
-import json
-import os
-import sys
-from pathlib import Path
-
-import yaml
-
 from filecrawler.libs.file import File
-from filecrawler.libs.parser import Parser
-from filecrawler.libs.process import Process
-from filecrawler.util.color import Color
-from filecrawler.util.logger import Logger
 from filecrawler.parserbase import ParserBase
 
 
@@ -21,7 +10,6 @@ class WindowsBinParser(ParserBase):
         super().__init__('Windows Bin Parser', 'Parser for Windows Bin files')
 
     def parse(self, file: File) -> dict:
-        from filecrawler.config import Configuration
         data = {'content': ''}
 
         #TODO: Implementar parser
